# Maxim Python Library

Python SDK to integrate Maxim AI. More info at [Maxim Site](https://getmaxim.ai). Maxim is an enterprise grade evaluation and monitoring platform for your GenAI applications.

## Version changelog

### v1.0.0

* Public beta release
